==> chromium-browser-16.0.912.77.tar.xz: chromium-browser-16.0.912.77/src/media/filters/file_data_source.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef MEDIA_FILTERS_FILE_DATA_SOURCE_H_
#define MEDIA_FILTERS_FILE_DATA_SOURCE_H_

#include <string>

#include "base/gtest_prod_util.h"
#include "base/synchronization/lock.h"
#include "media/base/filters.h"

namespace media {

// Basic data source that treats the URL as a file path, and uses the file
// system to read data for a media pipeline.
class MEDIA_EXPORT FileDataSource : public DataSource {
 public:
  FileDataSource();
  FileDataSource(bool disable_file_size);
  virtual ~FileDataSource();

  PipelineStatus Initialize(const std::string& url);

  // Implementation of Filter.
  virtual void set_host(FilterHost* filter_host);
  virtual void Stop(const base::Closure& callback);

  // Implementation of DataSource.
  virtual void Read(int64 position, size_t size, uint8* data,
                    const DataSource::ReadCallback& read_callback);
  virtual bool GetSize(int64* size_out);
  virtual bool IsStreaming();
  virtual void SetPreload(Preload preload);
  virtual void SetBitrate(int bitrate);

 private:
  // Only allow factories and tests to create this object.
  //
  // TODO(scherkus): I'm getting tired of these factories getting in the way
  // of my tests!!!
  FRIEND_TEST_ALL_PREFIXES(FileDataSourceTest, OpenFile);
  FRIEND_TEST_ALL_PREFIXES(FileDataSourceTest, ReadData);
  FRIEND_TEST_ALL_PREFIXES(FileDataSourceTest, Seek);

  // Informs the host of changes in total and buffered bytes.
  void UpdateHostBytes();

  // File handle.  NULL if not initialized or an error occurs.
  FILE* file_;

  // Size of the file in bytes.
  int64 file_size_;

  // True if the FileDataSource should ignore its set file size, false
  // otherwise.
  bool disable_file_size_;

  // Critical section that protects all of the DataSource methods to prevent
  // a Stop from happening while in the middle of a file I/O operation.
  // TODO(ralphl): Ideally this would use asynchronous I/O or we will know
  // that we will block for a short period of time in reads.  Otherwise, we can
  // hang the pipeline Stop.
  base::Lock lock_;

  DISALLOW_COPY_AND_ASSIGN(FileDataSource);
};

}  // namespace media

#endif  // MEDIA_FILTERS_FILE_DATA_SOURCE_H_

==> chromium-browser-24.0.1312.52.tar.xz: chromium-browser-24.0.1312.52/src/media/filters/file_data_source.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef MEDIA_FILTERS_FILE_DATA_SOURCE_H_
#define MEDIA_FILTERS_FILE_DATA_SOURCE_H_

#include <string>

#include "base/gtest_prod_util.h"
#include "base/synchronization/lock.h"
#include "media/base/data_source.h"

namespace media {

// Basic data source that treats the URL as a file path, and uses the file
// system to read data for a media pipeline.
class MEDIA_EXPORT FileDataSource : public DataSource {
 public:
  FileDataSource();
  FileDataSource(bool disable_file_size);

  bool Initialize(const std::string& url);

  // Implementation of DataSource.
  virtual void set_host(DataSourceHost* host) OVERRIDE;
  virtual void Stop(const base::Closure& callback) OVERRIDE;
  virtual void Read(int64 position, int size, uint8* data,
                    const DataSource::ReadCB& read_cb) OVERRIDE;
  virtual bool GetSize(int64* size_out) OVERRIDE;
  virtual bool IsStreaming() OVERRIDE;
  virtual void SetBitrate(int bitrate) OVERRIDE;

 protected:
  virtual ~FileDataSource();

 private:
  // Informs the host of changes in total and buffered bytes.
  void UpdateHostBytes();

  // File handle.  NULL if not initialized or an error occurs.
  FILE* file_;

  // Size of the file in bytes.
  int64 file_size_;

  // True if the FileDataSource should ignore its set file size, false
  // otherwise.
  bool disable_file_size_;

  // Critical section that protects all of the DataSource methods to prevent
  // a Stop from happening while in the middle of a file I/O operation.
  // TODO(ralphl): Ideally this would use asynchronous I/O or we will know
  // that we will block for a short period of time in reads.  Otherwise, we can
  // hang the pipeline Stop.
  base::Lock lock_;

  DISALLOW_COPY_AND_ASSIGN(FileDataSource);
};

}  // namespace media

#endif  // MEDIA_FILTERS_FILE_DATA_SOURCE_H_
